Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1031)

Unified Diff: webrtc/api/objc/RTCVideoSource+Private.h

Issue 1770003002: Renamed VideoSourceInterface to VideoTrackSourceInterface. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Rebased Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/api/objc/RTCVideoSource+Private.h
diff --git a/webrtc/api/objc/RTCVideoSource+Private.h b/webrtc/api/objc/RTCVideoSource+Private.h
index c363d3390e5378d16e5a009bfe59ed13d7ff65de..be064bdd9b0e176674173b7272a2c701a63b8fa7 100644
--- a/webrtc/api/objc/RTCVideoSource+Private.h
+++ b/webrtc/api/objc/RTCVideoSource+Private.h
@@ -17,15 +17,16 @@ NS_ASSUME_NONNULL_BEGIN
@interface RTCVideoSource ()
/**
* The VideoSourceInterface object passed to this RTCVideoSource during
* construction.
*/
@property(nonatomic, readonly)
- rtc::scoped_refptr<webrtc::VideoSourceInterface> nativeVideoSource;
+ rtc::scoped_refptr<webrtc::VideoTrackSourceInterface>
+ nativeVideoSource;
-/** Initialize an RTCVideoSource from a native VideoSourceInterface. */
+/** Initialize an RTCVideoSource from a native VideoTrackSourceInterface. */
- (instancetype)initWithNativeVideoSource:
- (rtc::scoped_refptr<webrtc::VideoSourceInterface>)nativeVideoSource
+ (rtc::scoped_refptr<webrtc::VideoTrackSourceInterface>)nativeVideoSource
NS_DESIGNATED_INITIALIZER;
+ (webrtc::MediaSourceInterface::SourceState)nativeSourceStateForState:

Powered by Google App Engine
This is Rietveld 408576698
@@ -17,15 +17,16 @@ NS_ASSUME_NONNULL_BEGIN
/**
- * The VideoSourceInterface object passed to this RTCVideoSource during
+ * The VideoTrackSourceInterface object passed to this RTCVideoSource during
* construction.
*/